@@ -494,7 +494,25 @@ def create_app(user_ctx=None):
                                 "max_cli_version": str(
                                     ctx.get("max_cli_version", "0.10.33")
                                 )
-                            }
+                            },
+                            "latestLocalVersionInfo": {
+                                "outOfDate": ctx.get("out_of_date", False),
+                                "latestVersionString": str(ctx.get("latest_version", "0.9.42")),
+                            },
+                        },
+                    }
+                }
+            )
+        if "query ProbeServerCapabilities" in body["query"]:
+            return json.dumps(
+                  {
+                    "data": {
+                        "QueryType": {"fields": [{"name": "serverInfo"},]},
+                        "ServerInfoType": {
+                            "fields": [
+                                {"name": "cliVersionInfo"},
+                                {"name": "latestLocalVersionInfo"},
+                            ]
                         },
                     }
                 }
@@ -1413,7 +1431,7 @@ class ParseCTX(object):
 
     @property
     def config_wandb(self):
-        return self.config["_wandb"]["value"]
+        return self.config.get("_wandb", {}).get("value", {})
 
     @property
     def telemetry(self):
